.. Magic-Wormhole-Mailbox-Server documentation master file, created by
   sphinx-quickstart on Sun Nov 12 10:24:09 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Magic-Wormhole-Mailbox-Server: backend server for magic-wormhole
================================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   welcome

   server-protocol


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
